==> freecad_0.16.6712%2Bdfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/Plot/resources/translations/Plot_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-CN" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>绘图编辑工具</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>绘图</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>配置坐标轴</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>设置座标轴参数</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="110"/>
      <source>Show/Hide grid</source>
      <translation>显示/隐藏网格</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="113"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>在选定绘图上显示/隐藏网格</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="154"/>
      <source>Set labels</source>
      <translation>设置标签</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="157"/>
      <source>Set title and axes labels</source>
      <translation>设置标题和坐标轴标签</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="137"/>
      <source>Show/Hide legend</source>
      <translation>显示/隐藏图例</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="140"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>在选定绘图上显示/隐藏图例</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="171"/>
      <source>Set positions and sizes</source>
      <translation>设置位置和大小</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="174"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>设置标签和图例位置及大小</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>保存绘图</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>保存绘图到图像文件</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>配置系列</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>配置绘图样式和标签</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>配置坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Active axes</source>
      <translation>活动坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Apply to all axes</source>
      <translation>应用于所有坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="225"/>
      <source>Dimensions</source>
      <translation>尺寸</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="230"/>
      <source>X axis position</source>
      <translation>X轴位置</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="235"/>
      <source>Y axis position</source>
      <translation>Y轴位置</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="205"/>
      <source>Scales</source>
      <translation>比例</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="210"/>
      <source>X auto</source>
      <translation>X轴自动</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="215"/>
      <source>Y auto</source>
      <translation>Y轴自动</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="240"/>
      <source>Index of the active axes</source>
      <translation>活动坐标轴索引</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="245"/>
      <source>Add new axes to the plot</source>
      <translation>向绘图添加新轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="251"/>
      <source>Remove selected axes</source>
      <translation>删除所选坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>选中以对所有坐标轴应用转换</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="263"/>
      <source>Left bound of axes</source>
      <translation>坐标轴左边界</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="269"/>
      <source>Right bound of axes</source>
      <translation>坐标轴右边界</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="275"/>
      <source>Bottom bound of axes</source>
      <translation>坐标轴下边界</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="281"/>
      <source>Top bound of axes</source>
      <translation>坐标轴上边界</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Outward offset of X axis</source>
      <translation>X轴外部偏移量</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="293"/>
      <source>Outward offset of Y axis</source>
      <translation>Y轴外部偏移量</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="299"/>
      <source>X axis scale autoselection</source>
      <translation>自动选择X轴比例</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="305"/>
      <source>Y axis scale autoselection</source>
      <translation>自动选择Y轴比例</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>未找到matplotlib,因此绘图模块未能加载</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>未找到matplotlib,绘图模块将被禁用</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>必须选中绘图文档以保存</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="365"/>
      <source>Axes 0 can not be deleted</source>
      <translation>无法删除坐标轴0</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>网格必须于绘图文档顶层激活</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="126"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>图例必须于绘图文档顶层激活</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>设置标签</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Active axes</source>
      <translation>活动坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="143"/>
      <source>Title</source>
      <translation>标题</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="148"/>
      <source>X label</source>
      <translation>X标签</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="153"/>
      <source>Y label</source>
      <translation>Y标签</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>活动坐标轴索引</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>标题(与活动轴关联)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Title font size</source>
      <translation>标题字体大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>X axis title</source>
      <translation>X轴标题</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="181"/>
      <source>X axis title font size</source>
      <translation>X轴标题字体大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>Y axis title</source>
      <translation>Y轴标题</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="193"/>
      <source>Y axis title font size</source>
      <translation>Y轴标题字体大小</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>设置位置和大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="126"/>
      <source>Position</source>
      <translation>位置</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Size</source>
      <translation>大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>List of modificable items</source>
      <translation>可改项目列表</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>X轴项目位置</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>Y item position</source>
      <translation>Y轴项目位置</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="156"/>
      <source>Item size</source>
      <translation>项目大小</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="128"/>
      <source>Save figure</source>
      <translation>保存图表</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Inches</source>
      <translation>英寸</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>Dots per Inch</source>
      <translation>每英寸点数</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="145"/>
      <source>Output image file path</source>
      <translation>输出图像文件路径</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="151"/>
      <source>Show a file selection dialog</source>
      <translation>显示选择文件对话框</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>X向图像大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Y image size</source>
      <translation>Y向图像大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation type="unfinished">Dots per point, with size will define output image resolution</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>No label</source>
      <translation>无标签</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="160"/>
      <source>Remove serie</source>
      <translation>删除系列</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="196"/>
      <source>Line style</source>
      <translation>线条样式</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>标记</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>配置系列</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>List of available series</source>
      <translation>可用系列列表</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Line title</source>
      <translation>直线标题</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Marker style</source>
      <translation>标记样式</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>Line width</source>
      <translation>线宽</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="214"/>
      <source>Marker size</source>
      <translation>标记大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Line and marker color</source>
      <translation>直线和标记颜色</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="226"/>
      <source>Removes this serie</source>
      <translation>删除此系列</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="190"/>
      <source>If checked serie will not be considered for legend</source>
      <translation>选中则系列不作为图例</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1%2Bdfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Plot/resources/translations/Plot_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="zh-CN" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="46"/>
      <source>Plot edition tools</source>
      <translation>图表编辑工具</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="49"/>
      <source>Plot</source>
      <translation>图表</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure axes</source>
      <translation>配置坐标轴</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="68"/>
      <source>Configure the axes parameters</source>
      <translation>设置坐标轴参数</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="112"/>
      <source>Show/Hide grid</source>
      <translation>显示/隐藏网格</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="115"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>在选定图表上显示/隐藏网格</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="155"/>
      <source>Set labels</source>
      <translation>设置标签</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="158"/>
      <source>Set title and axes labels</source>
      <translation>设置标题和坐标轴标签</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="138"/>
      <source>Show/Hide legend</source>
      <translation>显示/隐藏图例</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="141"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>在选定图表上显示/隐藏图例</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="172"/>
      <source>Set positions and sizes</source>
      <translation>设置位置和大小</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="175"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>设置标签和图例位置及大小</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save plot</source>
      <translation>保存图表</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="51"/>
      <source>Save the plot as an image file</source>
      <translation>保存图表到图像文件</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series</source>
      <translation>配置系列</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="87"/>
      <source>Configure series drawing style and label</source>
      <translation>配置图表样式及标签</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Configure axes</source>
      <translation>配置坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Active axes</source>
      <translation>选中的坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="216"/>
      <source>Apply to all axes</source>
      <translation>应用于所有坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Dimensions</source>
      <translation>尺寸</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="224"/>
      <source>X axis position</source>
      <translation>X轴位置</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="228"/>
      <source>Y axis position</source>
      <translation>Y轴位置</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="204"/>
      <source>Scales</source>
      <translation>比例</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>X auto</source>
      <translation>X轴自动</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="212"/>
      <source>Y auto</source>
      <translation>Y轴自动</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="232"/>
      <source>Index of the active axes</source>
      <translation>选中坐标轴索引</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="237"/>
      <source>Add new axes to the plot</source>
      <translation>向图表添加新坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="242"/>
      <source>Remove selected axes</source>
      <translation>删除所选坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="247"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>选中以对所有坐标轴应用变换</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="252"/>
      <source>Left bound of axes</source>
      <translation>坐标轴左边界</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Right bound of axes</source>
      <translation>坐标轴右边界</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="262"/>
      <source>Bottom bound of axes</source>
      <translation>坐标轴下边界</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="267"/>
      <source>Top bound of axes</source>
      <translation>坐标轴上边界</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="272"/>
      <source>Outward offset of X axis</source>
      <translation>X轴外部偏移量</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="277"/>
      <source>Outward offset of Y axis</source>
      <translation>Y轴外部偏移量</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="282"/>
      <source>X axis scale autoselection</source>
      <translation>自动选择X轴比例</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Y axis scale autoselection</source>
      <translation>自动选择Y轴比例</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="47"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>未找到matplotlib, 因此图表模块未能加载</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="58"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>未找到matplotlib, 图表模块将被禁用</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="48"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>必须选中图表文档以保存</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="346"/>
      <source>Axes 0 can not be deleted</source>
      <translation>无法删除坐标轴0</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="101"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>网格必须于图表文档顶层激活</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="129"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>图例必须于图表文档顶层激活</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Set labels</source>
      <translation>设置标签</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="142"/>
      <source>Active axes</source>
      <translation>选中的坐标轴</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="146"/>
      <source>Title</source>
      <translation>标题</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>X label</source>
      <translation>X标签</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>Y label</source>
      <translation>Y标签</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>选中坐标轴索引</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>标题(与活动轴关联)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="168"/>
      <source>Title font size</source>
      <translation>标题字体大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="173"/>
      <source>X axis title</source>
      <translation>X轴标题</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>X axis title font size</source>
      <translation>X轴标题字体大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="183"/>
      <source>Y axis title</source>
      <translation>Y轴标题</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="188"/>
      <source>Y axis title font size</source>
      <translation>Y轴标题字体大小</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="124"/>
      <source>Set positions and sizes</source>
      <translation>设置位置和大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="129"/>
      <source>Position</source>
      <translation>位置</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="134"/>
      <source>Size</source>
      <translation>大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>X轴项目位置</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Y item position</source>
      <translation>Y轴项目位置</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>Item size</source>
      <translation>项目大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>List of modifiable items</source>
      <translation>可更改项目的列表</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Save figure</source>
      <translation>保存图表</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="137"/>
      <source>Inches</source>
      <translation>英寸</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="142"/>
      <source>Dots per Inch</source>
      <translation>每英寸点数(DPI)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="147"/>
      <source>Output image file path</source>
      <translation>输出图像文件路径</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="152"/>
      <source>Show a file selection dialog</source>
      <translation>显示选择文件对话框</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>X向图像大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="162"/>
      <source>Y image size</source>
      <translation>Y向图像大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="168"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>每点内的点数, 根据尺寸来定义输出影像的解析度</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>No label</source>
      <translation>无标签</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="192"/>
      <source>Line style</source>
      <translation>线条样式</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>标记</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="152"/>
      <source>Configure series</source>
      <translation>配置系列</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="177"/>
      <source>List of available series</source>
      <translation>可用系列列表</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="182"/>
      <source>Line title</source>
      <translation>直线标题</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="197"/>
      <source>Marker style</source>
      <translation>标记样式</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Line width</source>
      <translation>线宽</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="207"/>
      <source>Marker size</source>
      <translation>标记大小</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="212"/>
      <source>Line and marker color</source>
      <translation>直线和标记颜色</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="162"/>
      <source>Remove series</source>
      <translation>删除系列</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>If checked, series will not be considered for legend</source>
      <translation>如果选中，系列不会被认作图例</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="217"/>
      <source>Removes this series</source>
      <translation>删除此系列</translation>
    </message>
  </context>
</TS>
